.. Copyright (C) 2017      Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2019      Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.neurodebian`` role allows you to configure the NeuroDebian__
repository and install packages from it.

NeuroDebian provides a large collection of popular neuroscience research
software for the Debian operating system as well as Ubuntu and other
derivatives.

.. __: http://neuro.debian.net/
